/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'cy', {
	border: 'Dangos ymyl y ffrâm',
	noUrl: 'Rhowch URL yr iframe',
	scrolling: 'Galluogi bariau sgrolio',
	title: 'Priodweddau IFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
